Cheetah.DirectiveAnalyzer module — Cheetah3 - The Python-Powered Template Engine

# Cheetah.DirectiveAnalyzer module

class `Cheetah.DirectiveAnalyzer.` `AnalysisCompiler`(source=None, file=None, moduleName='DynamicallyCompiledCheetahTemplate', mainClassName=None, mainMethodName=None, baseclassName=None, extraImportStatements=None, settings=None)

  Bases: `Cheetah.Compiler.ModuleCompiler`

  `parserClass`

    alias of `Analyzer`

class `Cheetah.DirectiveAnalyzer.` `Analyzer`(*args, **kwargs)

  Bases: `Cheetah.Parser._HighLevelParser`

  `eatDirective`()

`Cheetah.DirectiveAnalyzer.` `analyze`(source)

`Cheetah.DirectiveAnalyzer.` `main`()

`Cheetah.DirectiveAnalyzer.` `main_dir`(opts)

`Cheetah.DirectiveAnalyzer.` `main_file`(f)